@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -196,11 +196,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "alaskisk normaltid",
-               "",
+               "AKST",
                "alaskisk sommartid",
-               "",
+               "AKDT",
                "alaskisk tid",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "normaltid for Amazonas",
@@ -348,11 +348,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "normaltid for den nordamerikanske atlanterhavskysten",
-               "",
+               "AST",
                "sommartid for den nordamerikanske atlanterhavskysten",
-               "",
+               "ADT",
                "tidssone for den nordamerikanske atlanterhavskysten",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "normaltid for Brasilia",
@@ -620,27 +620,27 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "sentraleuropeisk standardtid",
-               "",
+               "CET",
                "sentraleuropeisk sommartid",
-               "",
+               "CEST",
                "sentraleuropeisk tid",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "austeuropeisk standardtid",
-               "",
+               "EET",
                "austeuropeisk sommartid",
-               "",
+               "EEST",
                "austeuropeisk tid",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "vesteuropeisk standardtid",
-               "",
+               "WET",
                "vesteuropeisk sommartid",
-               "",
+               "WEST",
                "vesteuropeisk tid",
-               "",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "normaltid for den meksikanske stillehavskysten",
@@ -652,27 +652,27 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] America_Central = new String[] {
                "normaltid for sentrale Nord-Amerika",
-               "",
+               "CST",
                "sommartid for sentrale Nord-Amerika",
-               "",
+               "CDT",
                "tidssone for sentrale Nord-Amerika",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "normaltid for den nordamerikanske austkysten",
-               "",
+               "EST",
                "sommartid for den nordamerikansk austkysten",
-               "",
+               "EDT",
                "tidssone for den nordamerikanske austkysten",
-               "",
+               "ET",
             };
         final String[] America_Pacific = new String[] {
                "normaltid for den nordamerikanske stillehavskysten",
-               "",
+               "PST",
                "sommartid for den nordamerikanske stillehavskysten",
-               "",
+               "PDT",
                "tidssone for den nordamerikanske stillehavskysten",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "tidssone for Dei franske s\u00f8rterritoria",
@@ -692,11 +692,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "normaltid for Hawaii og Aleutene",
-               "",
+               "HAST",
                "sommartid for Hawaii og Aleutene",
-               "",
+               "HADT",
                "tidssone for Hawaii og Aleutene",
-               "",
+               "HAT",
             };
         final String[] Phoenix_Islands = new String[] {
                "tidssone for Phoenix\u00f8yane",
@@ -716,11 +716,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "normaltid for Rocky Mountains (USA)",
-               "",
+               "MST",
                "sommartid for Rocky Mountains (USA)",
-               "",
+               "MDT",
                "tidssone for Rocky Mountains (USA)",
-               "",
+               "MT",
             };
         final String[] Mexico_Northwest = new String[] {
                "normaltid for nordvestlege Mexico",
