@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -247,7 +247,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -287,6 +287,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Africa/Nouakchott", GMT },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -331,6 +332,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -392,10 +394,8 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Algier" },
             { "timezone.excity.America/Belize", "Belmopan" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.America/Cayman", "Inslas Cayman" },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
             { "timezone.excity.Asia/Kamchatka", "Kamtschatka" },
             { "timezone.excity.Asia/Samarkand", "Samarcanda" },
